@@ -2,7 +2,7 @@
  * Seahorse
  *
  * Copyright (C) 2003 Jacob Perkins
- * Copyright (C) 2005 Nate Nielsen
+ * Copyright (C) 2005 Stefan Walter
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,35 +20,11 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <gnome.h>
+#include <string.h>
 
 #include "seahorse-key.h"
 #include "seahorse-context.h"
-#include "seahorse-key-source.h"
-
-gboolean 
-seahorse_key_predicate_match (SeahorseKeyPredicate *kl, SeahorseKey *skey)
-{
-    /* Now go for all the fields */
-    if (kl->ktype && (kl->ktype != skey->ktype))
-        return FALSE;
-    if (kl->keyid && (kl->keyid != skey->keyid))
-        return FALSE;
-    if (kl->location && (kl->location != skey->location))
-        return FALSE;
-    if (kl->etype && (kl->etype != skey->etype)) 
-        return FALSE;
-    if (kl->flags && !(kl->flags & skey->flags))
-        return FALSE;
-    if (kl->nflags && (kl->nflags & skey->flags))
-        return FALSE;
-    if (kl->sksrc && (kl->sksrc != skey->sksrc))
-        return FALSE;
-    /* Any custom stuff last */
-    if (kl->custom && !((kl->custom)(skey, kl->custom_data)))
-        return FALSE;
-    return TRUE;
-}
+#include "seahorse-source.h"
 
 enum {
     PROP_0,
@@ -58,9 +34,9 @@ enum {
     PROP_KEY_DESC,
     PROP_KTYPE,
     PROP_ETYPE,
-    PROP_FLAGS,
-    PROP_LOCATION,
-    PROP_LOADED
+    PROP_LOADED,
+    PROP_MARKUP,
+    PROP_DISPLAY_NAME
 };
 
 /* Special fields */
@@ -73,14 +49,7 @@ enum {
 
 GQuark special_properties[PROP_SPECIAL_MAX] = { 0 };
 
-enum {
-    CHANGED,
-    LAST_SIGNAL
-};
-
-static guint signals[LAST_SIGNAL] = { 0 };
-
-G_DEFINE_TYPE (SeahorseKey, seahorse_key, GTK_TYPE_OBJECT);
+G_DEFINE_TYPE (SeahorseKey, seahorse_key, SEAHORSE_TYPE_OBJECT);
 
 /* -----------------------------------------------------------------------------
  * OBJECT 
@@ -96,16 +65,12 @@ static void
 seahorse_key_set_property (GObject *object, guint prop_id, const GValue *value, 
                            GParamSpec *pspec)
 {
-    SeahorseKey *skey = SEAHORSE_KEY (object);
-    
-    switch (prop_id) {
-    case PROP_KEY_SOURCE:
-        g_assert (!skey->sksrc);
-        skey->sksrc = g_value_get_object (value);
-        g_return_if_fail (SEAHORSE_IS_KEY_SOURCE (skey->sksrc));
-        g_object_add_weak_pointer (G_OBJECT (skey->sksrc), (gpointer*)&(skey->sksrc));
-        break;
-    }
+	switch (prop_id) {
+	case PROP_KEY_SOURCE:
+		/* Pass on to SeahorseObject */
+		g_object_set_property (object, "source", value);
+		break;
+	}
 }
 
 static void
@@ -116,11 +81,19 @@ seahorse_key_get_property (GObject *object, guint prop_id, GValue *value,
     
     switch (prop_id) {
     case PROP_KEY_SOURCE:
-        g_value_set_object (value, skey->sksrc);
+	/* Pass on to SeahorseObject */
+	g_object_get_property(object, "source", value); 
         break;
     case PROP_KEY_ID:
-        g_value_set_uint (value, skey->keyid);
+	/* Pass on to SeahorseObject */
+	g_object_get_property(object, "id", value);
         break;
+    case PROP_MARKUP:
+	g_value_take_string (value, seahorse_key_get_name_markup (skey, 0));
+	break;
+    case PROP_DISPLAY_NAME:
+	g_value_take_string (value, seahorse_key_get_name_cn (skey, 0));
+	break;
     case PROP_RAW_ID:
         g_value_set_string (value, skey->rawid);
         break;
@@ -128,16 +101,12 @@ seahorse_key_get_property (GObject *object, guint prop_id, GValue *value,
         g_value_set_string (value, skey->keydesc);
         break;
     case PROP_KTYPE:
-        g_value_set_uint (value, skey->ktype);
+	/* Pass on to SeahorseObject */
+	g_object_get_property(object, "tag", value);
         break;
     case PROP_ETYPE:
-        g_value_set_uint (value, skey->etype);
-    case PROP_FLAGS:
-        g_value_set_uint (value, skey->flags);
-        break;
-    case PROP_LOCATION:
-        g_value_set_uint (value, skey->location);
-        break;
+	/* Pass on to SeahorseObject */
+	g_object_get_property(object, "usage", value);
     case PROP_LOADED:
         g_value_set_uint (value, skey->loaded);
         break;
@@ -150,10 +119,17 @@ seahorse_key_object_finalize (GObject *gobject)
     G_OBJECT_CLASS (seahorse_key_parent_class)->finalize (gobject);
 }
 
+static gchar*
+seahorse_key_get_markup (SeahorseObject *obj)
+{
+	return seahorse_key_get_name_markup (SEAHORSE_KEY (obj), 0);
+}
+
 static void
 seahorse_key_class_init (SeahorseKeyClass *klass)
 {
     GObjectClass *gobject_class;
+    SeahorseObjectClass *object_class;
     
     seahorse_key_parent_class = g_type_class_peek_parent (klass);
     gobject_class = G_OBJECT_CLASS (klass);
@@ -162,11 +138,14 @@ seahorse_key_class_init (SeahorseKeyClass *klass)
     gobject_class->set_property = seahorse_key_set_property;
     gobject_class->get_property = seahorse_key_get_property;
     
-    klass->changed = NULL;
+    object_class = SEAHORSE_OBJECT_CLASS (klass);
+    object_class->get_display_name = (gpointer)seahorse_key_get_display_name;
+    object_class->get_markup = seahorse_key_get_markup;
+    object_class->get_stock_id = (gpointer)seahorse_key_get_stock_id;
     
     g_object_class_install_property (gobject_class, PROP_KEY_SOURCE,
         g_param_spec_object ("key-source", "Key Source", "Key Source that this key belongs to", 
-                             SEAHORSE_TYPE_KEY_SOURCE, G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+                             SEAHORSE_TYPE_SOURCE, G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 
     g_object_class_install_property (gobject_class, PROP_KEY_ID,
         g_param_spec_uint ("key-id", "Key ID", "Key identifier", 
@@ -186,24 +165,20 @@ seahorse_key_class_init (SeahorseKeyClass *klass)
 
     g_object_class_install_property (gobject_class, PROP_ETYPE,
         g_param_spec_uint ("etype", "Encrpyption Type", "Key encryption type", 
-                           0, G_MAXUINT, SKEY_ETYPE_NONE, G_PARAM_READABLE));
-
-    g_object_class_install_property (gobject_class, PROP_FLAGS,
-        g_param_spec_uint ("flags", "Key Flags", "Flags on capabilities of key. See SeahorseKeyFlags", 
-                           0, G_MAXUINT, 0, G_PARAM_READABLE));
-
-    g_object_class_install_property (gobject_class, PROP_LOCATION,
-        g_param_spec_uint ("location", "Key Location", "Where the key is stored. See SeahorseKeyLoc", 
-                           0, G_MAXUINT, SKEY_LOC_INVALID, G_PARAM_READABLE));
+                           0, G_MAXUINT, SEAHORSE_USAGE_NONE, G_PARAM_READABLE));
 
     g_object_class_install_property (gobject_class, PROP_LOADED,
         g_param_spec_uint ("loaded", "Loaded Information", "Which parts of the key are loaded. See SeahorseKeyLoaded", 
                            0, G_MAXUINT, SKEY_INFO_NONE, G_PARAM_READABLE));
 
-    signals[CHANGED] = g_signal_new ("changed", G_OBJECT_CLASS_TYPE (gobject_class),
-        G_SIGNAL_RUN_LAST,  G_STRUCT_OFFSET (SeahorseKeyClass, changed),
-        NULL, NULL, g_cclosure_marshal_VOID__INT, G_TYPE_NONE, 1, G_TYPE_INT);
-        
+    g_object_class_install_property (gobject_class, PROP_DISPLAY_NAME,
+        g_param_spec_string ("display-name", "Key Label", "Label of this key",
+                             NULL, G_PARAM_READABLE));
+
+    g_object_class_install_property (gobject_class, PROP_MARKUP,
+        g_param_spec_string ("markup", "Key Label Markup", "Markup for this key",
+                             NULL, G_PARAM_READABLE));
+
     /* Some special fields */
     special_properties[PROP_SPECIAL_KEY_ID] = g_quark_from_static_string ("key-id");
     special_properties[PROP_SPECIAL_DISPLAY_NAME] = g_quark_from_static_string ("display-name");
@@ -214,39 +189,12 @@ seahorse_key_class_init (SeahorseKeyClass *klass)
  * PUBLIC 
  */
 
-/**
- * seahorse_key_destroy:
- * @skey: #SeahorseKey to destroy
- *
- * Conveniance wrapper for gtk_object_destroy(). Emits destroy signal for @skey.
- **/
-void
-seahorse_key_destroy (SeahorseKey *skey)
-{
-    g_return_if_fail (skey != NULL && GTK_IS_OBJECT (skey));
-    gtk_object_destroy (GTK_OBJECT (skey));
-}
-
-/**
- * seahorse_key_changed:
- * @skey: #SeahorseKey that changed
- * @change: #SeahorseKeyChange type
- *
- * Emits the changed signal for @skey with @change.
- **/
-void
-seahorse_key_changed (SeahorseKey *skey, SeahorseKeyChange change)
-{
-    g_return_if_fail (skey != NULL && SEAHORSE_IS_KEY (skey));
-    g_signal_emit (G_OBJECT (skey), signals[CHANGED], 0, change);
-}
-
 GQuark
 seahorse_key_get_keyid (SeahorseKey *skey)
 {
     g_return_val_if_fail (skey && SEAHORSE_IS_KEY (skey), 0);
-    return skey->keyid;
-}    
+    return SEAHORSE_OBJECT (skey)->_id;
+}
 
 const gchar*      
 seahorse_key_get_short_keyid (SeahorseKey *skey)
@@ -255,7 +203,7 @@ seahorse_key_get_short_keyid (SeahorseKey *skey)
     guint l;
     
     g_return_val_if_fail (skey && SEAHORSE_IS_KEY (skey), NULL);
-    id = g_quark_to_string (skey->keyid);
+    id = g_quark_to_string (SEAHORSE_OBJECT (skey)->_id);
     
     l = strlen (id);
     if (l > 8)
@@ -270,14 +218,13 @@ seahorse_key_get_short_keyid (SeahorseKey *skey)
  * 
  * Gets the key source for the given key
  * 
- * Returns: A #SeahorseKeySource
+ * Returns: A #SeahorseSource
  **/
-struct _SeahorseKeySource* 
+SeahorseSource* 
 seahorse_key_get_source  (SeahorseKey *skey)
 {
-    g_return_val_if_fail (SEAHORSE_IS_KEY (skey), NULL);
-    g_return_val_if_fail (SEAHORSE_IS_KEY_SOURCE (skey->sksrc), NULL);
-    return skey->sksrc;
+	g_return_val_if_fail (SEAHORSE_IS_KEY (skey), NULL);
+	return seahorse_object_get_source (SEAHORSE_OBJECT (skey));
 }
 
 const gchar*
@@ -290,14 +237,14 @@ GQuark
 seahorse_key_get_ktype (SeahorseKey *skey)
 {
     g_return_val_if_fail (SEAHORSE_IS_KEY (skey), SKEY_UNKNOWN);
-    return skey->ktype;
+    return SEAHORSE_OBJECT (skey)->_tag;
 }
 
-SeahorseKeyEType
-seahorse_key_get_etype (SeahorseKey *skey)
+SeahorseUsage
+seahorse_key_get_usage (SeahorseKey *skey)
 {
-    g_return_val_if_fail (SEAHORSE_IS_KEY (skey), SKEY_ETYPE_NONE);
-    return skey->etype;
+    g_return_val_if_fail (SEAHORSE_IS_KEY (skey), SEAHORSE_USAGE_NONE);
+    return SEAHORSE_OBJECT (skey)->_usage;
 }
 /**
  * seahorse_key_get_loaded_info
@@ -314,18 +261,18 @@ seahorse_key_get_loaded (SeahorseKey *skey)
     return skey->loaded;
 }
 
-SeahorseKeyLoc 
+SeahorseLocation
 seahorse_key_get_location (SeahorseKey *skey)
 {
-    g_return_val_if_fail (SEAHORSE_IS_KEY (skey), SKEY_LOC_INVALID);
-    return skey->location;
+    g_return_val_if_fail (SEAHORSE_IS_KEY (skey), SEAHORSE_LOCATION_INVALID);
+    return SEAHORSE_OBJECT (skey)->_location;
 }
 
 guint
 seahorse_key_get_flags (SeahorseKey *skey)
 {
     g_return_val_if_fail (SEAHORSE_IS_KEY (skey), 0);
-    return skey->flags;
+    return SEAHORSE_OBJECT (skey)->_flags;
 }
 
 guint
@@ -460,29 +407,14 @@ seahorse_key_get_length (SeahorseKey *skey)
     return length;
 }
 
-const gchar*
+gchar*
 seahorse_key_get_stock_id (SeahorseKey *skey)
 {
-    const gchar* stock_id;
+    gchar* stock_id;
     g_object_get (skey, "stock-id", &stock_id, NULL);
     return stock_id;
 }
 
-void
-seahorse_key_set_preferred (SeahorseKey *skey, SeahorseKey *preferred)
-{
-    /* 
-     * We don't ref, because the SeahorseContext takes care of 
-     * keeping things sane. 
-     */
-    
-    if (preferred != skey->preferred) {
-        skey->preferred = preferred;
-        seahorse_key_changed (skey, SKEY_CHANGE_PREFERRED);
-    }
-}
-
-
 gboolean
 seahorse_key_lookup_property (SeahorseKey *skey, guint uid, const gchar *field, GValue *value)
 {
@@ -494,7 +426,7 @@ seahorse_key_lookup_property (SeahorseKey *skey, guint uid, const gchar *field,
     
     /* The key-id for these guys contains the uid */
     if (qfield == special_properties[PROP_SPECIAL_KEY_ID]) {
-        text = seahorse_context_key_to_dbus (SCTX_APP (), skey, uid);
+        text = seahorse_context_object_to_dbus (SCTX_APP (), SEAHORSE_OBJECT (skey), uid);
         g_value_init (value, G_TYPE_STRING);
         g_value_take_string (value, text);
         return TRUE;
